summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/redmine/sudo_mode.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/redmine/sudo_mode.rb b/lib/redmine/sudo_mode.rb
index 3f2749cd5..6d3ac6878 100644
--- a/lib/redmine/sudo_mode.rb
+++ b/lib/redmine/sudo_mode.rb
@@ -108,7 +108,7 @@ module Redmine
@sudo_form ||= SudoMode::Form.new
@sudo_form.original_fields = params.slice( *param_names )
# a simple 'render "sudo_mode/new"' works when used directly inside an
# action, but not when called from a before_filter:
respond_to do |format|
format.html { render 'sudo_mode/new' }
format.js { render 'sudo_mode/new' }
@@ -168,7 +168,7 @@ module Redmine
actions = args.dup
options = actions.extract_options!
filter = SudoRequestFilter.new Array(options[:parameters]), Array(options[:only])
- before_filter filter, only: actions
+ before_action filter, only: actions
end
end
end
@@ -108,7 +108,7 @@ module Redmine
# a simple 'render "sudo_mode/new"' works when used directly inside an
- # action, but not when called from a before_filter:
+ # action, but not when called from a before_action:
respond_to do |format|
format.html { render 'sudo_mode/new' }